Index: src/runtime/runtime-scopes.cc |
diff --git a/src/runtime/runtime-scopes.cc b/src/runtime/runtime-scopes.cc |
index 265ce83c6eb767c6148c2d351e44f4f65e904917..c5890e7071795daf7788577b899410f8b26584bf 100644 |
--- a/src/runtime/runtime-scopes.cc |
+++ b/src/runtime/runtime-scopes.cc |
@@ -979,10 +979,10 @@ RUNTIME_FUNCTION(Runtime_DeleteLookupSlot) { |
return isolate->heap()->false_value(); |
} |
// The slot was found in a JSObject, either a context extension object, |
// the global object, or the subject of a with. Try to delete it |
// (respecting DONT_DELETE). |
- Handle<JSObject> object = Handle<JSObject>::cast(holder); |
+ Handle<JSReceiver> object = Handle<JSReceiver>::cast(holder); |
Maybe<bool> result = JSReceiver::DeleteProperty(object, name); |
MAYBE_RETURN(result, isolate->heap()->exception()); |
return isolate->heap()->ToBoolean(result.FromJust()); |
@@ -979,10 +979,10 @@ RUNTIME_FUNCTION(Runtime_DeleteLookupSlot) { |
return isolate->heap()->false_value(); |
} |
- // The slot was found in a JSObject, either a context extension object, |
+ // The slot was found in a JSReceiver, either a context extension object, |
// the global object, or the subject of a with. Try to delete it |
// (respecting DONT_DELETE). |